==> qt6-qtshadertools-6.3.1p0.tgz: lib/cmake/Qt6ShaderTools/Qt6ShaderToolsConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtModuleConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

cmake_minimum_required(VERSION 3.16...3.21)

include(CMakeFindDependencyMacro)

get_filename_component(_import_prefix "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_import_prefix "${_import_prefix}" REALPATH)

# Extra cmake code begin

# Extra cmake code end

# Find required dependencies, if any.
if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsDependencies.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsDependencies.cmake")
endif()

# If *ConfigDependencies.cmake exists, the variable value will be defined there.
# Don't override it in that case.
if(NOT DEFINED "Qt6ShaderTools_FOUND")
    set("Qt6ShaderTools_FOUND" TRUE)
endif()

if (NOT QT_NO_CREATE_TARGETS AND Qt6ShaderTools_FOUND)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsTargets.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsAdditionalTargetInfo.cmake")
    if(NOT QT_NO_CREATE_VERSIONLESS_TARGETS)
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsVersionlessTargets.cmake")
    endif()

    # DEPRECATED
    # Provide old style variables for includes, compile definitions, etc.
    # These variables are deprecated and only provided on a best-effort basis to facilitate porting.
    # Consider using target_link_libraries(app PRIVATE Qt6ShaderTools) instead.
    set(Qt6ShaderTools_LIBRARIES "Qt6::ShaderTools")

    get_target_property(_Qt6ShaderTools_OWN_INCLUDE_DIRS
                        Qt6::ShaderTools INTERFACE_INCLUDE_DIRECTORIES)
    if(NOT _Qt6ShaderTools_OWN_INCLUDE_DIRS)
        set(_Qt6ShaderTools_OWN_INCLUDE_DIRS "")
    endif()

    if(TARGET Qt6::ShaderToolsPrivate)
        get_target_property(_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS
                            Qt6::ShaderToolsPrivate INTERFACE_INCLUDE_DIRECTORIES)
        if(NOT _Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS)
            set(_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS "")
        endif()
    endif()

    get_target_property(Qt6ShaderTools_DEFINITIONS
                        Qt6::ShaderTools INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6ShaderTools_DEFINITIONS)
        set(Qt6ShaderTools_DEFINITIONS "")
    else()
        list(TRANSFORM Qt6ShaderTools_DEFINITIONS PREPEND "-D")
    endif()

    get_target_property(Qt6ShaderTools_COMPILE_DEFINITIONS
                        Qt6::ShaderTools INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6ShaderTools_COMPILE_DEFINITIONS)
        set(Qt6ShaderTools_COMPILE_DEFINITIONS "")
    endif()

    set(Qt6ShaderTools_INCLUDE_DIRS
        ${_Qt6ShaderTools_OWN_INCLUDE_DIRS})

    set(Qt6ShaderTools_PRIVATE_INCLUDE_DIRS
        ${_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS})

    foreach(_module_dep ${_Qt6ShaderTools_MODULE_DEPENDENCIES})
        list(APPEND Qt6ShaderTools_INCLUDE_DIRS
             ${Qt6${_module_dep}_INCLUDE_DIRS})
        list(APPEND Qt6ShaderTools_PRIVATE_INCLUDE_DIRS
             ${Qt6${_module_dep}_PRIVATE_INCLUDE_DIRS})
        list(APPEND Qt6ShaderTools_DEFINITIONS
             ${Qt6${_module_dep}_DEFINITIONS})
        list(APPEND Qt6ShaderTools_COMPILE_DEFINITIONS
             ${Qt6${_module_dep}_COMPILE_DEFINITIONS})
    endforeach()

    list(REMOVE_DUPLICATES Qt6ShaderTools_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_COMPILE_DEFINITIONS)
endif()

if (TARGET Qt6::ShaderTools)
    foreach(extra_cmake_include )
        include("${CMAKE_CURRENT_LIST_DIR}/${extra_cmake_include}")
    endforeach()

    qt_make_features_available(Qt6::ShaderTools)

    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsPlugins.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsPlugins.cmake")
    endif()

    list(APPEND QT_ALL_MODULES_FOUND_VIA_FIND_PACKAGE "ShaderTools")

    get_target_property(_qt_module_target_type "Qt6::ShaderTools" TYPE)
    if(NOT _qt_module_target_type STREQUAL "INTERFACE_LIBRARY")
        get_target_property(_qt_module_plugin_types
                            Qt6::ShaderTools MODULE_PLUGIN_TYPES)
        if(_qt_module_plugin_types)
            list(APPEND QT_ALL_PLUGIN_TYPES_FOUND_VIA_FIND_PACKAGE "${_qt_module_plugin_types}")
        endif()
    endif()


    # Load Module's BuildInternals should any exist
    if (Qt6BuildInternals_DIR AND
        EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsBuildInternals.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsBuildInternals.cmake")
    endif()
else()

    set(Qt6ShaderTools_FOUND FALSE)
    if(NOT DEFINED Qt6ShaderTools_NOT_FOUND_MESSAGE)
        set(Qt6ShaderTools_NOT_FOUND_MESSAGE
            "Target \"Qt6::ShaderTools\" was not found. ${Qt6ShaderTools_extra_not_found_message}")

        if(QT_NO_CREATE_TARGETS)
            string(APPEND Qt6ShaderTools_NOT_FOUND_MESSAGE
                "Possibly due to QT_NO_CREATE_TARGETS being set to TRUE and thus "
                "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsTargets.cmake was not "
                "included to define the target.")
        endif()
    endif()
endif()

==> qt6-qtshadertools-6.5.2.tgz: lib/cmake/Qt6ShaderTools/Qt6ShaderToolsConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was QtModuleConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

cmake_minimum_required(VERSION 3.16...3.21)

include(CMakeFindDependencyMacro)

get_filename_component(_import_prefix "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_import_prefix "${_import_prefix}" REALPATH)

# Extra cmake code begin

# Extra cmake code end

# Find required dependencies, if any.
if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsDependencies.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsDependencies.cmake")
    _qt_internal_suggest_dependency_debugging(ShaderTools
        __qt_ShaderTools_pkg ${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE)
endif()

# If *ConfigDependencies.cmake exists, the variable value will be defined there.
# Don't override it in that case.
if(NOT DEFINED "Qt6ShaderTools_FOUND")
    set("Qt6ShaderTools_FOUND" TRUE)
endif()

if (NOT QT_NO_CREATE_TARGETS AND Qt6ShaderTools_FOUND)
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsTargets.cmake")
    include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsAdditionalTargetInfo.cmake")
    if(NOT QT_NO_CREATE_VERSIONLESS_TARGETS)
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsVersionlessTargets.cmake")
    endif()

    # DEPRECATED
    # Provide old style variables for includes, compile definitions, etc.
    # These variables are deprecated and only provided on a best-effort basis to facilitate porting.
    # Consider using target_link_libraries(app PRIVATE Qt6ShaderTools) instead.
    set(Qt6ShaderTools_LIBRARIES "Qt6::ShaderTools")

    get_target_property(_Qt6ShaderTools_OWN_INCLUDE_DIRS
                        Qt6::ShaderTools INTERFACE_INCLUDE_DIRECTORIES)
    if(NOT _Qt6ShaderTools_OWN_INCLUDE_DIRS)
        set(_Qt6ShaderTools_OWN_INCLUDE_DIRS "")
    endif()

    if(TARGET Qt6::ShaderToolsPrivate)
        get_target_property(_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS
                            Qt6::ShaderToolsPrivate INTERFACE_INCLUDE_DIRECTORIES)
        if(NOT _Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS)
            set(_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS "")
        endif()
    endif()

    get_target_property(Qt6ShaderTools_DEFINITIONS
                        Qt6::ShaderTools INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6ShaderTools_DEFINITIONS)
        set(Qt6ShaderTools_DEFINITIONS "")
    else()
        list(TRANSFORM Qt6ShaderTools_DEFINITIONS PREPEND "-D")
    endif()

    get_target_property(Qt6ShaderTools_COMPILE_DEFINITIONS
                        Qt6::ShaderTools INTERFACE_COMPILE_DEFINITIONS)
    if(NOT Qt6ShaderTools_COMPILE_DEFINITIONS)
        set(Qt6ShaderTools_COMPILE_DEFINITIONS "")
    endif()

    set(Qt6ShaderTools_INCLUDE_DIRS
        ${_Qt6ShaderTools_OWN_INCLUDE_DIRS})

    set(Qt6ShaderTools_PRIVATE_INCLUDE_DIRS
        ${_Qt6ShaderTools_OWN_PRIVATE_INCLUDE_DIRS})

    foreach(_module_dep ${_Qt6ShaderTools_MODULE_DEPENDENCIES})
        list(APPEND Qt6ShaderTools_INCLUDE_DIRS
             ${Qt6${_module_dep}_INCLUDE_DIRS})
        list(APPEND Qt6ShaderTools_PRIVATE_INCLUDE_DIRS
             ${Qt6${_module_dep}_PRIVATE_INCLUDE_DIRS})
        list(APPEND Qt6ShaderTools_DEFINITIONS
             ${Qt6${_module_dep}_DEFINITIONS})
        list(APPEND Qt6ShaderTools_COMPILE_DEFINITIONS
             ${Qt6${_module_dep}_COMPILE_DEFINITIONS})
    endforeach()

    list(REMOVE_DUPLICATES Qt6ShaderTools_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt6ShaderTools_COMPILE_DEFINITIONS)
endif()

if (TARGET Qt6::ShaderTools)
    qt_make_features_available(Qt6::ShaderTools)

    foreach(extra_cmake_include )
        include("${CMAKE_CURRENT_LIST_DIR}/${extra_cmake_include}")
    endforeach()

    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsPlugins.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsPlugins.cmake")
    endif()

    list(APPEND QT_ALL_MODULES_FOUND_VIA_FIND_PACKAGE "ShaderTools")

    get_target_property(_qt_module_target_type "Qt6::ShaderTools" TYPE)
    if(NOT _qt_module_target_type STREQUAL "INTERFACE_LIBRARY")
        get_target_property(_qt_module_plugin_types
                            Qt6::ShaderTools MODULE_PLUGIN_TYPES)
        if(_qt_module_plugin_types)
            list(APPEND QT_ALL_PLUGIN_TYPES_FOUND_VIA_FIND_PACKAGE "${_qt_module_plugin_types}")
        endif()
    endif()


    # Load Module's BuildInternals should any exist
    if (Qt6BuildInternals_DIR AND
        EXISTS "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsBuildInternals.cmake")
        include("${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsBuildInternals.cmake")
    endif()
else()

    set(Qt6ShaderTools_FOUND FALSE)
    if(NOT DEFINED Qt6ShaderTools_NOT_FOUND_MESSAGE)
        set(Qt6ShaderTools_NOT_FOUND_MESSAGE
            "Target \"Qt6::ShaderTools\" was not found.")

        if(QT_NO_CREATE_TARGETS)
            string(APPEND Qt6ShaderTools_NOT_FOUND_MESSAGE
                "Possibly due to QT_NO_CREATE_TARGETS being set to TRUE and thus "
                "${CMAKE_CURRENT_LIST_DIR}/Qt6ShaderToolsTargets.cmake was not "
                "included to define the target.")
        endif()
    endif()
endif()
